.. rst-class:: detail

Noop
===============

.. currentmodule:: compas_rrc

.. autoclass:: Noop

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~Noop.__init__
        ~Noop.from_msg
    
    